# MaterialClassificationResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**material_classification_reference_number** | **str** |  | 
**material_classification_coordinates** | **object** |  | 
**material_classification_classification** | [**MaterialClassificationClassificationResponse**](MaterialClassificationClassificationResponse.md) |  | 
**material_classification_classification_string** | **str** |  | 
**hazardous_material_type** | [**list[HazardousMaterialTypeResponse]**](HazardousMaterialTypeResponse.md) |  | [optional] 
**hazardous_material_type_string** | **list[str]** |  | [optional] 
**hazardous_material_type_other_description** | **str** |  | [optional] 
**layer_affected** | [**list[LayerAffectedResponse]**](LayerAffectedResponse.md) |  | 
**layer_affected_string** | **list[str]** |  | 
**location_types** | [**list[LocationTypeResponse]**](LocationTypeResponse.md) |  | 
**location_types_string** | **list[str]** |  | 
**sample_date** | **datetime** |  | 
**location_description** | **str** |  | 
**date_created** | **datetime** |  | 
**ha_swa_code** | **str** |  | 
**ha_organisation_name** | **str** |  | 
**usrn** | **float** |  | 
**street_name** | **str** |  | 
**town** | **str** |  | [optional] 
**area_name** | **str** |  | [optional] 
**raised_by_swa_code** | **str** |  | 
**raised_by_organisation_name** | **str** |  | 
**file** | **AllOfMaterialClassificationResponseFile** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

